vim.fn.setenv("MACOSX_DEPLOYMENT_TARGET", "12.2.1")

vim.cmd [[packadd packer.nvim]]

return require('packer').startup(function(use)
	-- Packer can manage itself
	use('wbthomason/packer.nvim')

	-- LSP
	-- mason - manager for lsp, dap, linter
	use("williamboman/mason.nvim")
	use("williamboman/mason-lspconfig.nvim")
	use('neovim/nvim-lspconfig')
	use('hrsh7th/cmp-nvim-lsp')
	use('hrsh7th/cmp-nvim-lua')
	use('hrsh7th/cmp-buffer')
	use('hrsh7th/cmp-path')
	use('hrsh7th/nvim-cmp')
	use('saadparwaiz1/cmp_luasnip')

	-- Linter
	use('jose-elias-alvarez/null-ls.nvim')
	local null_ls = require('null-ls')

	require('null-ls').setup({
		sources = { null_ls.builtins.diagnostics.selene }
	})

	-- colorschemes
	use('ayu-theme/ayu-vim')
	use('morhetz/gruvbox')
	use('dikiaap/minimalist')
	use('jacoborus/tender.vim')
	use('jpo/vim-railscasts-theme')
	use('rainux/vim-desert-warm-256')
	use('ajmwagar/vim-deus')
	use("rebelot/kanagawa.nvim")
	-- airline
	use('nvim-lualine/lualine.nvim')

	-- Git
	use('kdheepak/lazygit.nvim')

	-- Sessions
	use("tpope/vim-obsession")

	-- SuperTab
	use('ervandew/supertab')

	-- Vim-surround
	use('tpope/vim-surround')

	-- Slime, for tmux repl-ing
	use('jpalardy/vim-slime')

	-- Telescope, fuzzy finding
	use('nvim-lua/plenary.nvim')
	use('nvim-telescope/telescope.nvim')
	use { 'nvim-telescope/telescope-fzf-native.nvim', run = 'make' }
	use("nvim-telescope/telescope-file-browser.nvim")

	-- Treesitter
	use { 'nvim-treesitter/nvim-treesitter', run = ':TSUpdate' }

	-- Devicons
	use('kyazdani42/nvim-web-devicons')

	-- Registry history
	use {
		"AckslD/nvim-neoclip.lua",
		requires = {
			{ 'kkharji/sqlite.lua', module = 'sqlite' },
			{ 'nvim-telescope/telescope.nvim' },
		},
		config = function()
			require('neoclip').setup({
				enable_persistent_history = true,
				continuous_sync = true
			}
			)
		end,
	}

	-- Buffers
	use('matbme/JABS.nvim')
	require("jabs").setup {}

	-- Comments
	use {
		'numToStr/Comment.nvim',
		config = function()
			require('Comment').setup()
		end
	}

	-- Git Repo Telescope
	use { 'cljoly/telescope-repo.nvim' }

	-- Greeter
	use {
		'goolord/alpha-nvim',
		requires = { 'nvim-tree/nvim-web-devicons' },
		config = function()
			require 'alpha'.setup(require 'alpha.themes.startify'.config)
		end
	}

	-- Which-Key
	use {
		"folke/which-key.nvim",
		config = function()
			require("which-key").setup {
				-- your configuration comes here
				-- or leave it empty to use the default settings
				-- refer to the configuration section below
			}
		end
	}

	-- Close brackets
	use {
		"windwp/nvim-autopairs",
		config = function() require("nvim-autopairs").setup {} end
	}

	-- Cursor line
	use('yamatsum/nvim-cursorline')
	require('nvim-cursorline').setup {
		cursorline = {
			enable = true,
			timeout = 0,
			number = true,
		},
		cursorword = {
			enable = false,
		}
	}

	-- file ex
	use {
		"nvim-neo-tree/neo-tree.nvim",
		branch = "v2.x",
		requires = {
			"nvim-lua/plenary.nvim",
			"nvim-tree/nvim-web-devicons", -- not strictly required, but recommended
			"MunifTanjim/nui.nvim",
		}
	}

	-- Indent lines
	require("packer").startup(function()
		use "lukas-reineke/indent-blankline.nvim"
	end)

	-- Object Explorer
	use 'simrat39/symbols-outline.nvim'

end
)
